==> cbpl-unicom-1.0.39.2-20230427.044613-2-sources.jar: com/elitesland/cbpl/unicom/config/UnicomConfig.java <==
package com.elitesland.cbpl.unicom.config;

import cn.hutool.core.collection.CollUtil;
import com.elitesland.cbpl.unicom.proxy.UnicomAdapterProxy;
import com.elitesland.cbpl.unicom.proxy.UnicomInterfaceProxy;
import lombok.extern.slf4j.Slf4j;
import org.reflections.Reflections;
import org.reflections.util.ClasspathHelper;
import org.reflections.util.ConfigurationBuilder;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.context.EnvironmentAware;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.env.Environment;

import java.net.URL;
import java.util.ArrayList;
import java.util.Collection;

import static org.reflections.scanners.Scanners.SubTypes;
import static org.reflections.scanners.Scanners.TypesAnnotated;

/**
 * @author eric.hao
 * @since 2022/06/29
 */
@Slf4j
@Configuration
public class UnicomConfig implements EnvironmentAware {

    private UnicomProperties properties;

    /**
     * 反射类扫描注册
     */
    @Bean
    @ConditionalOnMissingBean
    public Reflections reflections() {
        logger.info("[UNICOM] load reflections.");
        Collection<URL> urls = new ArrayList<>();
        if (CollUtil.isNotEmpty(properties.getBasePackage())) {
            for (String basePackage : properties.getBasePackage()) {
                urls.addAll(ClasspathHelper.forPackage(basePackage));
            }
        }
        return new Reflections(new ConfigurationBuilder()
                .setUrls(urls).addScanners(TypesAnnotated, SubTypes));
    }

    /**
     * 接口拦截代理
     */
    @Bean
    public UnicomInterfaceProxy unicomInterfaceProxy(Reflections reflections) {
        logger.info("[UNICOM] load unicom interface proxy.");
        return new UnicomInterfaceProxy(reflections, properties);
    }

    @Bean
    public UnicomAdapterProxy unicomAdapterProxy(Reflections reflections) {
        logger.info("[UNICOM] load unicom adapter proxy.");
        return new UnicomAdapterProxy(reflections, properties);
    }

    @Override
    public void setEnvironment(Environment environment) {
        this.properties = UnicomProperties.from(environment);
    }
}

==> cbpl-unicom-1.0.40-20230427.061016-1-sources.jar: com/elitesland/cbpl/unicom/config/UnicomConfig.java <==
package com.elitesland.cbpl.unicom.config;

import cn.hutool.core.collection.CollUtil;
import com.elitesland.cbpl.unicom.proxy.UnicomAdapterProxy;
import com.elitesland.cbpl.unicom.proxy.UnicomInterfaceProxy;
import lombok.extern.slf4j.Slf4j;
import org.reflections.Reflections;
import org.reflections.util.ClasspathHelper;
import org.reflections.util.ConfigurationBuilder;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.context.EnvironmentAware;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.env.Environment;

import java.net.URL;
import java.util.ArrayList;
import java.util.Collection;

import static org.reflections.scanners.Scanners.SubTypes;
import static org.reflections.scanners.Scanners.TypesAnnotated;

/**
 * @author eric.hao
 * @since 2022/06/29
 */
@Slf4j
@Configuration
public class UnicomConfig implements EnvironmentAware {

    private UnicomProperties properties;

    /**
     * 反射类扫描注册
     */
    @Bean
    @ConditionalOnMissingBean
    public Reflections reflections() {
        if (!properties.isEnabled()) {
            return null;
        }
        logger.info("[UNICOM] loading reflections.");
        Collection<URL> urls = new ArrayList<>();
        if (CollUtil.isNotEmpty(properties.getBasePackage())) {
            for (String basePackage : properties.getBasePackage()) {
                urls.addAll(ClasspathHelper.forPackage(basePackage));
            }
        }
        return new Reflections(new ConfigurationBuilder()
                .setUrls(urls).addScanners(TypesAnnotated, SubTypes));
    }

    /**
     * 接口拦截代理
     */
    @Bean
    public UnicomInterfaceProxy unicomInterfaceProxy(Reflections reflections) {
        logger.info("[UNICOM] load unicom interface proxy.");
        return new UnicomInterfaceProxy(reflections, properties);
    }

    @Bean
    public UnicomAdapterProxy unicomAdapterProxy(Reflections reflections) {
        logger.info("[UNICOM] load unicom adapter proxy.");
        return new UnicomAdapterProxy(reflections, properties);
    }

    @Override
    public void setEnvironment(Environment environment) {
        this.properties = UnicomProperties.from(environment);
    }
}
